using System;
using System.Runtime.InteropServices;


namespace NETFileDialog
{
	/// <summary>
	/// Summary description for NETOpenFileDialog
	/// This class wraps the .NET OpenFileDialog class so that it can be
	/// forced modal to a parent window outside the .NET environment
	/// (specifically, LabVIEW 7.x)
	/// 
	/// Mark Smith
	/// mesmith@sandia.gov
	/// 17 Dec 04
	/// 
	/// </summary>
  public class NETOpenFileDialog
  {

    private System.Windows.Forms.OpenFileDialog myDialog;

    public NETOpenFileDialog() 
    {
      //
      // TODO: Add constructor logic here
      //
      myDialog = new System.Windows.Forms.OpenFileDialog();
    }

    

    public bool MultiSelect
    {
      get
      {
        return myDialog.Multiselect;
      }
      set
      {
        myDialog.Multiselect = value;
      }
    }

    public string Filter
    {
      get
      {
        return myDialog.Filter;
      }
      set
      {
        myDialog.Filter = value;
      }
    }

    public string[] FileNames
    {
      get
      {
        return myDialog.FileNames;
      }
    }

    public string InitialDirectory
    {
      get
      {
        return myDialog.InitialDirectory;
      }
      set
      {
        myDialog.InitialDirectory = value;
      }
    }

    public string Title
    {
      get
      {
        return myDialog.Title;
      }
      set
      {
        myDialog.Title = value;
      }
    }


    public System.Windows.Forms.DialogResult ShowMyDialog(string windowName)
    {
      IntPtr hwnd = FindWindow(null, windowName);
      if (hwnd != IntPtr.Zero)
      {
        // do something with the handle if desired
        //...
      }
      else 
      {
        throw new System.Exception(windowName + " not found!");

      }
      WindowWrapper handle = new WindowWrapper(hwnd);
      return myDialog.ShowDialog(handle);
    }

    //use the Windows api to get the handle to the parent window
    [DllImport("user32.dll", CharSet=CharSet.Auto, SetLastError=true)]
    public static extern IntPtr FindWindow(string ClassName, string WindowText);


    //this class implements the IWin32Window interface and wraps the windows
    //handle
    private class WindowWrapper : System.Windows.Forms.IWin32Window
    {
      public WindowWrapper(IntPtr handle)
      {
        _hwnd = handle;
      }

      public IntPtr Handle
      {
        get { return _hwnd; }
      }

      private IntPtr _hwnd;
    }
	}
}
